pub enum ExtFunctionResult {
Return(MontyObject),
Error(MontyException),
Future(u32),
NotFound(String),
}Expand description
Return value or exception from an external function.
Variants
Return(MontyObject)
Continues execution with the return value from the external function.
Error(MontyException)
Continues execution with the exception raised by the external function.
Future(u32)
Pending future — the external function is a coroutine.
The u32 is the call_id from the FunctionCall that created this
snapshot. It is used to track the pending future so it can be resolved
later via ResolveFutures::resume().
NotFound(String)
The function was not found, should result in a NameError exception.