pub enum InvalidInputError {
InvalidType(Cow<'static, str>),
Resource(ResourceError),
}Expand description
Error returned when a MontyObject cannot be used as an input to code execution.
This can occur when:
- A
MontyObjectvariant (likeRepr) is only valid as an output, not an input - A resource limit is exceeded during conversion
Variants
InvalidType(Cow<'static, str>)
The input type is not valid for conversion to a runtime Value. Message explaining why the type is invalid.
Resource(ResourceError)
A resource limit was exceeded during conversion.
Implementations
Sourceimpl InvalidInputError
impl InvalidInputError
Sourcepub fn invalid_type(msg: impl Into<Cow<'static, str>>) -> Self
pub fn invalid_type(msg: impl Into<Cow<'static, str>>) -> Self
Creates a new InvalidInputError for the given type name.